//*----------------------------------------------------------------------------
//*         ATMEL Microcontroller Software Support  -  ROUSSET  -
//*----------------------------------------------------------------------------
//* The software is delivered "AS IS" without warranty or condition of any
//* kind, either express, implied or statutory. This includes without
//* limitation any warranty or condition with respect to merchantability or
//* fitness for any particular purpose, or against the infringements of
//* intellectual property rights of others.
//*----------------------------------------------------------------------------
//* File Name           : main.c
//* Object              : main application written in C
//* Creation            : JPP   16/Jun/2004
//*----------------------------------------------------------------------------

// Include Standard files
#include "AT91SAM7S64.h"
#include "lib_AT91SAM7S64.h"

#define LED (1<<18)
//*--------------------------------------------------------------------------------------
//* Function Name       : wait
//* Object              : Software waiting loop
//* Input Parameters    : none. Waiting time is defined by the global variable LedSpeed.
//* Output Parameters   : none
//*--------------------------------------------------------------------------------------
static void wait ( void )
{//* Begin
    volatile unsigned int waiting_time ;
     for(waiting_time = 0; waiting_time < 1000; waiting_time++) ;
}//* End

//*--------------------------------------------------------------------------------------
//* Function Name       : Main
//* Object              : Software entry point
//* Input Parameters    : none.
//* Output Parameters   : none.
//*--------------------------------------------------------------------------------------
int main(void)
{//* Begin
    int i;
	
    AT91F_PMC_EnablePeriphClock ( AT91C_BASE_PMC, 1 << AT91C_ID_PIOA ) ;

	AT91F_PIO_Enable(AT91C_BASE_PIOA, LED);
	AT91F_PIO_OutputEnable(AT91C_BASE_PIOA, LED);

	AT91F_SPI_CfgPIO();
	AT91F_SPI_CfgPMC();
	AT91F_SPI_Enable( AT91C_BASE_SPI );

	AT91C_BASE_SPI->SPI_MR =
		AT91C_SPI_MSTR |	/* we use MASTER only mode */
		AT91C_SPI_PS_FIXED | 	/* we only use Fixed Peripheral Select */
		AT91C_SPI_MODFDIS | 	/* no Fault protection since there is no second master */
		AT91C_SPI_PCS | 	/* no peripheral selected */
		((10<<24) & AT91C_SPI_DLYBCS);	/* 10 Clock Cycles betwenn two different chip selects */

	AT91C_BASE_SPI->SPI_CSR[0] = (48<<15);
	AT91C_BASE_SPI->SPI_CSR[1] = (48<<15); 
	AT91C_BASE_SPI->SPI_CSR[2] = (48<<15); 
	AT91C_BASE_SPI->SPI_CSR[3] = (48<<15);   
	 
	while(1) // Loop forever
	{
		AT91F_PIO_SetOutput(AT91C_BASE_PIOA, LED);
    	AT91F_SPI_PutChar(AT91C_BASE_SPI,0xFA,0);
		wait();
		AT91F_PIO_ClearOutput(AT91C_BASE_PIOA, LED);
		wait();
	}
}//* End
